==> docfbe_2_3_35_62.zip: docfbe_2_2_35_62/source/TCFbEDataSetEx.h <==
/*
    TCFbEDataSetEx.h    June 6, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#ifndef TCFbEDataSetExH
#define TCFbEDataSetExH
//---------------------------------------------------------------------------
// #include "Maprof.h"

#include "math.h"
#include "TCFbEToolkit.h"

#include "TCFbECustomTableEx.h"

#include "TCFbETableEx.h"
#include "TCFbERotatedTableEx.h"
#include "TCFbECell.h"
#include "TCFbENeighbor.h"

#include "TCFbESimilarityComputationAlgorithm.h"
#include "TCFbEPredictionAlgorithm.h"
//---------------------------------------------------------------------------
// Ăl
enum TCFbEValueBase { vbUnknown, vbValue, vbStandardizedValue, vbNormalizedValue, vbOrder, vbDoubleStandardizedValue, vbDoubleNormalizedValue, vbDoubleOrder };

// x[X̃ASYiabUnknown Ȃ abRow ƓlƂ݂Ȃ
enum TCFbEAlgorithmBase { abUnknown, abRow, abColumn };
//---------------------------------------------------------------------------
// Facade IȃNX
class TCFbEDataSetEx : public TCFbETableEx
{
public:
    // ANZT
    virtual void __fastcall SetValueByIndex(int TargetRowIndex, int TargetColumnIndex, double Value) {
        TCFbETableEx::SetValueByIndex(TargetRowIndex, TargetColumnIndex, Value);
        this->RePrepareCF(TargetRowIndex, TargetColumnIndex);
    }

    virtual void __fastcall UnableElementByIndex(int TargetRowIndex, int TargetColumnIndex) {
        TCFbETableEx::UnableElementByIndex(TargetRowIndex, TargetColumnIndex);
        this->RePrepareCF(TargetRowIndex, TargetColumnIndex);
    }

    virtual bool IsPrepared(void) { // CF ̏łĂ trueCłĂȂ false
        return this->FIsPrepared;
    }

    virtual TCFbECustomTableEx* __fastcall GetSimilarityComputationTable(void) {
//        return (TCFbECustomTableEx*)this->GetMainMediateTable()->GetChildCache("SimilarityComputationTable");
        return (TCFbECustomTableEx*)this->GetMainMediateTable()->GetChildCacheList()->Items[12];
    }

    virtual TCFbECustomTableEx* __fastcall GetPredictionTable(void) {
//        return (TCFbECustomTableEx*)this->GetMainMediateTable()->GetChildCache("PredictionTable");
        return (TCFbECustomTableEx*)this->GetMainMediateTable()->GetChildCacheList()->Items[13];
    }

    virtual TCFbETableEx* __fastcall GetMainMediateTable(void) {
        TCFbETableEx* SubMediateTable = this->GetSubMediateTable();
        if (SubMediateTable == NULL) {
//            return (TCFbETableEx*)this->GetChildCache("MainMediateTable");
            return (TCFbETableEx*)this->GetChildCacheList()->Items[12];
        }
//        return (TCFbETableEx*)this->GetSubMediateTable()->GetChildCache("MainMediateTable");
        return (TCFbETableEx*)this->GetSubMediateTable()->GetChildCacheList()->Items[12];
    }

    virtual TCFbETableEx* __fastcall GetSubMediateTable(void) {
        return (TCFbETableEx*)this->GetChildCache("SubMediateTable");
    }

    virtual double __fastcall GetSimilarity(AnsiString TargetRowLabel, AnsiString ComparedRowLabel) {
        return this->GetSimilarityByIndex(this->GetRowLabelList()->IndexOf(TargetRowLabel), this->GetRowLabelList()->IndexOf(ComparedRowLabel));
    }

    virtual double __fastcall GetPredictedValue(AnsiString TargetRowLabel, AnsiString TargetColumnLabel) {
        return this->GetPredictedValueByIndex(this->GetRowLabelList()->IndexOf(TargetRowLabel), this->GetColumnLabelList()->IndexOf(TargetColumnLabel));
    }

    virtual double __fastcall GetSimilarityByIndex(int TargetRowIndex, int ComparedRowIndex);
    virtual double __fastcall GetPredictedValueByIndex(int TargetRowIndex, int TargetColumnIndex);

    virtual TCFbESimilarityComputationAlgorithm*    GetSimilarityComputationAlgorithm(void) { return this->FSimilarityComputationAlgorithm; }
    virtual TCFbEPredictionAlgorithm*               GetPredictionAlgorithm(void) { return this->FPredictionAlgorithm; }
    
    virtual __fastcall TCFbEDataSetEx(void);   // RXgN^
    virtual __fastcall TCFbEDataSetEx(TStringList* SourceCsvStringList); // RXgN^
    __fastcall ~TCFbEDataSetEx();    // fXgN^

    virtual void    __fastcall PrepareCF(TCFbEValueBase ValueBase, TCFbEAlgorithmBase AlgorithmBase, TCFbESimilarityComputationAlgorithm* SimilarityComputationAlgorithm, TCFbEPredictionAlgorithm* PredictionAlgorithm, int NeighborhoodSize, bool DefaultValueEnabled, double DefaultValue, bool InverseCaseFrequencyEnabled, double CaseAmplifier);    // CF ̏siPredictionTable 

    virtual void __fastcall GetNearestNeighbors(int TargetRowIndex, int TargetColumnIndex, int NeighborhoodSize, TObjectList* NeighborList);    // TargetRowIndex ɑ΂ NearestNeigobors 𒲂ׂ

    virtual void    __fastcall FillColumns(TCFbEDataSetEx* BaseDataSet);    // BaseDataSet ɂāCthis ɂȂVȗƂĒǉ
    virtual bool    __fastcall IsConsistentWith(TCFbEDataSetEx* TargetDataSet);    // TargetDataSet Ǝѐ邩ǂ𒲂ׂ

    virtual double  __fastcall DisOrderingEx(int ColumnIndex, double Order);  // ColumnIndex ڂ Ordering ꂽl Order  DisOrdering ĕԂ
    virtual double  __fastcall DisDoubleNormalize(int RowIndex, int ColumnIndex, double DoubleNormalizedValue);    // RowIndex sځCColumnIndex ڂ DoubleNormalize ꂽl DoubleNormalizedValue  DisDoubleNormalize ĕԂ
    virtual double  __fastcall DisDoubleStandardize(int RowIndex, int ColumnIndex, double DoubleStandardizedValue);    // RowIndex sځCColumnIndex ڂ DoubleStandardize ꂽl DoubleStandardizedValue  DisDoubleStandardize ĕԂ
    virtual double  __fastcall DisDoubleOrdering(int RowIndex, int ColumnIndex, double DoubleOrder);    // RowIndex sځCColumnIndex ڂ DoubleOrdering ꂽl DoubleOrder  DisDoubleOrdering ĕԂ

    virtual void    __fastcall TemporallyUnable(int TargetRowIndex, int TargetColumnIndex); // TargetRowIndex, TargetColumnIndex ̃ZꎞI Enabled = false ɂ
    virtual void    __fastcall RecoverEnabled(void);    // ꎞI Enabled = false ɂĂZɂǂ

protected:
    virtual void __fastcall RePrepareCF(int TargetRowIndex, int TargetColumnIndex);
    virtual void __fastcall CellIsUpdatedByIndex(int RowIndex, int ColumnIndex) {
        if (this->IsPrepared()) {
            TCFbETableEx::CellIsUpdatedByIndex(RowIndex, ColumnIndex);
        }
    }

    TCFbEValueBase      FValueBase;
    TCFbEAlgorithmBase  FAlgorithmBase;
    TCFbESimilarityComputationAlgorithm*    FSimilarityComputationAlgorithm;
    TCFbEPredictionAlgorithm*               FPredictionAlgorithm;
    int     FNeighborhoodSize;
    bool    FDefaultValueEnabled;
    double  FDefaultValue;
    bool    FInverseCaseFrequencyEnabled;
    double  FCaseAmplifier;
    bool    FIsPrepared;

    int     TemporallyUnableRowIndex;
    int     TemporallyUnableColumnIndex;
    double  TemporallyUnableValue;

private:

};
//---------------------------------------------------------------------------
#endif

==> docfbe_2_3_36_63.zip: docfbe_2_3_36_63/source/TCFbEDataSetEx.h <==
/*
    TCFbEDataSetEx.h    June 6, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#ifndef TCFbEDataSetExH
#define TCFbEDataSetExH
//---------------------------------------------------------------------------
// #include "Maprof.h"

#include "math.h"
#include "TCFbEToolkit.h"
#include "TCFbETypes.h"

#include "TCFbECustomTableEx.h"

#include "TCFbETableEx.h"
#include "TCFbERotatedTableEx.h"
#include "TCFbECell.h"
#include "TCFbENeighbor.h"

#include "TCFbESimilarityComputationAlgorithm.h"
#include "TCFbEPredictionAlgorithm.h"
//---------------------------------------------------------------------------
// Facade IȃNX
class TCFbEDataSetEx : public TCFbETableEx
{
public:
    // ANZT
    virtual void __fastcall SetValueByIndex(int TargetRowIndex, int TargetColumnIndex, double Value) {
        TCFbETableEx::SetValueByIndex(TargetRowIndex, TargetColumnIndex, Value);
        this->RePrepareCF(TargetRowIndex, TargetColumnIndex);
    }

    virtual void __fastcall UnableElementByIndex(int TargetRowIndex, int TargetColumnIndex) {
        TCFbETableEx::UnableElementByIndex(TargetRowIndex, TargetColumnIndex);
        this->RePrepareCF(TargetRowIndex, TargetColumnIndex);
    }

    virtual bool IsPrepared(void) { // CF ̏łĂ trueCłĂȂ false
        return this->FIsPrepared;
    }

    virtual TCFbECustomTableEx* __fastcall GetSimilarityComputationTable(void) {
//        return (TCFbECustomTableEx*)this->GetMainMediateTable()->GetChildCache("SimilarityComputationTable");
        return (TCFbECustomTableEx*)this->GetMainMediateTable()->GetChildCacheList()->Items[12];
    }

    virtual TCFbECustomTableEx* __fastcall GetPredictionTable(void) {
//        return (TCFbECustomTableEx*)this->GetMainMediateTable()->GetChildCache("PredictionTable");
        return (TCFbECustomTableEx*)this->GetMainMediateTable()->GetChildCacheList()->Items[13];
    }

    virtual TCFbETableEx* __fastcall GetMainMediateTable(void) {
//        return (TCFbETableEx*)this->GetChildCache("MainMediateTable");
        return (TCFbETableEx*)this->GetChildCacheList()->Items[12];
    }

    virtual TCFbERowRowCachedTable* __fastcall GetSimilarityCache(void) {
        return (TCFbERowRowCachedTable*)this->GetSimilarityComputationTable()->GetChildCacheList()->Items[12];
    }

    virtual TCFbECustomTableEx* __fastcall GetPredictedValueCache(void) {
        return (TCFbECustomTableEx*)this->GetPredictionTable()->GetChildCacheList()->Items[12];
    }

    virtual double __fastcall GetSimilarity(AnsiString TargetRowLabel, AnsiString ComparedRowLabel) {
        return this->GetSimilarityByIndex(this->GetRowLabelList()->IndexOf(TargetRowLabel), this->GetRowLabelList()->IndexOf(ComparedRowLabel));
    }

    virtual double __fastcall GetPredictedValue(AnsiString TargetRowLabel, AnsiString TargetColumnLabel) {
        return this->GetPredictedValueByIndex(this->GetRowLabelList()->IndexOf(TargetRowLabel), this->GetColumnLabelList()->IndexOf(TargetColumnLabel));
    }

    virtual double __fastcall GetSimilarityByIndex(int TargetRowIndex, int ComparedRowIndex);
    virtual double __fastcall GetPredictedValueByIndex(int TargetRowIndex, int TargetColumnIndex);

    virtual TCFbESimilarityComputationAlgorithm*    GetSimilarityComputationAlgorithm(void) { return this->FSimilarityComputationAlgorithm; }
    virtual TCFbEPredictionAlgorithm*               GetPredictionAlgorithm(void) { return this->FPredictionAlgorithm; }
    
    virtual __fastcall TCFbEDataSetEx(void);   // RXgN^
    virtual __fastcall TCFbEDataSetEx(TStringList* SourceCsvStringList); // RXgN^
    __fastcall ~TCFbEDataSetEx();    // fXgN^

    virtual void    __fastcall PrepareCF(TCFbEValueBase ValueBase, TCFbEAlgorithmBase AlgorithmBase, TCFbESimilarityComputationAlgorithm* SimilarityComputationAlgorithm, TCFbEPredictionAlgorithm* PredictionAlgorithm, int NeighborhoodSize, bool DefaultValueEnabled, double DefaultValue, bool InverseCaseFrequencyEnabled, double CaseAmplifier);    // CF ̏siPredictionTable 

    virtual void __fastcall GetNearestNeighbors(int TargetRowIndex, int TargetColumnIndex, int NeighborhoodSize, TObjectList* NeighborList);    // TargetRowIndex ɑ΂ NearestNeigobors 𒲂ׂ

    virtual void    __fastcall FillColumns(TCFbEDataSetEx* BaseDataSet);    // BaseDataSet ɂāCthis ɂȂVȗƂĒǉ
    virtual bool    __fastcall IsConsistentWith(TCFbEDataSetEx* TargetDataSet);    // TargetDataSet Ǝѐ邩ǂ𒲂ׂ

    virtual double  __fastcall DisOrderingEx(int ColumnIndex, double Order);  // ColumnIndex ڂ Ordering ꂽl Order  DisOrdering ĕԂ

    virtual void    __fastcall TemporallyUnable(int TargetRowIndex, int TargetColumnIndex); // TargetRowIndex, TargetColumnIndex ̃ZꎞI Enabled = false ɂ
    virtual void    __fastcall RecoverEnabled(void);    // ꎞI Enabled = false ɂĂZɂǂ

protected:
    virtual void __fastcall RePrepareCF(int TargetRowIndex, int TargetColumnIndex);
    virtual void __fastcall CellIsUpdatedByIndex(int RowIndex, int ColumnIndex) {
        if (this->IsPrepared()) {
            TCFbETableEx::CellIsUpdatedByIndex(RowIndex, ColumnIndex);
        }
    }

    TCFbEValueBase      FValueBase;
    TCFbEAlgorithmBase  FAlgorithmBase;
    TCFbESimilarityComputationAlgorithm*    FSimilarityComputationAlgorithm;
    TCFbEPredictionAlgorithm*               FPredictionAlgorithm;
    int     FNeighborhoodSize;
    bool    FDefaultValueEnabled;
    double  FDefaultValue;
    bool    FInverseCaseFrequencyEnabled;
    double  FCaseAmplifier;
    bool    FIsPrepared;

    int     TemporallyUnableRowIndex;
    int     TemporallyUnableColumnIndex;
    double  TemporallyUnableValue;

private:

};
//---------------------------------------------------------------------------
#endif
